Learn R Programming

containr (version 0.1.1)

.validate_file_arg: Validate a file argument

Description

Internal helper used by generate_dockerfile() to check that optional file arguments (e.g. data_file, code_file, misc_file) are valid.

Usage

.validate_file_arg(arg_name, value)

Value

A normalized file path if validation succeeds, or NULL

if the input was NULL.

Arguments

arg_name

Character string, the name of the argument being checked (used only in error messages).

value

A character path to a file, or NULL.