Automates the process of containerizing 'R' projects. The core function of 'containr' is 'generate_dockerfile()', which analyzes an 'R' project's environment and dependencies via an 'renv' lock file and generates a ready-to-use 'Dockerfile' that encapsulates the computational setup. The package helps researchers build portable and consistent workflows so that analyses can be reliably shared, archived, and rerun across systems. See R Core Team (2025) https://www.R-project.org/, Ushey et al. (2025) https://CRAN.R-project.org/package=renv, and Docker Inc. (2025) https://www.docker.com/.
Maintainer: Erwin Lares erwin.lares@wisc.edu
Useful links: